@@ -7,7 +7,7 @@ module.exports = function (db) {
         function (username, password, done) {
             console.log('LocalStrategy');
 
-            db.db('oauth').table('users').filter(function (ff) {
+            db.table('users').filter(function (ff) {
                 return ff('providers').contains(function (cc) {
                     return cc('id').eq(username)
                         .and(cc('provider').eq('local'))
